@@ -1289,6 +1289,19 @@ extern int channel_get_max(t_channel const * channel)
   return channel->maxmembers;
 }
 
+extern int channel_set_max(t_channel * channel, int maxmembers)
+{
+  if (!channel)
+  {
+    eventlog(eventlog_level_error,__FUNCTION__,"got NULL channel");
+    return 0;
+  }
+
+  if (maxmembers)
+    channel->maxmembers = maxmembers;
+  return 1;
+}
+
 extern int channel_get_curr(t_channel const * channel)
 {
   if (!channel)
@@ -1424,9 +1437,7 @@ extern t_channel * channellist_find_channel_by_name(char const * name, char cons
 		 * channel that would otherwise match. */
                 if ( ((!channel->country && !foundlang) || !country || 
 		      (channel->country && country && (strcmp(channel->country, country)==0))) &&
-	             ((!channel->realmname && !realmname) || 
-		      (channel->realmname && realmname && (strcmp(channel->realmname, realmname)==0))) )
-
+	             (!channel->realmname || !realmname || !strcmp(channel->realmname, realmname)) )
 		{
 		    if (channel->maxmembers==-1 || channel->currmembers<channel->maxmembers) 
 		    {
