@@ -828,7 +828,7 @@ static int game_report(t_game * game)
 		realcount,game->players,game->results,ladder_info,
 		discisloss?ladder_option_disconnectisloss:ladder_option_none)<0)
 	    {
-		eventlog(eventlog_level_error,__FUNCTION__,"unable to update ladder stats");
+		eventlog(eventlog_level_info,__FUNCTION__,"unable to update ladder stats");
 		xfree(ladder_info);
 		ladder_info = NULL;
 	    }
@@ -1695,6 +1695,22 @@ extern int game_del_player(t_game * game, t_connection * c)
     return -1;
 }
 
+extern t_account * game_get_player(t_game * game, unsigned int i)
+{
+	if (!game)
+	{
+		eventlog(eventlog_level_error,__FUNCTION__,"got NULL game");
+		return NULL;
+	}
+	
+	if (!(i<game->count))
+	{
+		eventlog(eventlog_level_error,__FUNCTION__,"requested illegal player id %u",i);
+		return NULL;
+	}
+	   
+	return game->players[i];
+}
 
 extern int game_set_report(t_game * game, t_account * account, char const * rephead, char const * repbody)
 {
