@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2001  Marco Ziech (mmz@gmx.net)
  * Copyright (C) 2005  Bryan Biedenkapp (gatekeep@gmail.com)
+ * Copyright (C) 2006  Pelish (pelish@gmail.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -511,11 +512,11 @@ static int _handle_pong_command(t_connection * conn, int numparams, char ** para
 	    char * sname;
 
 	    if (numparams>=1) {  
-	        val = atoi(params[0]);
+	        val = strtoul(params[0],NULL,10);
 		sname = params[0];
 	    }
 	    else if (text) {
-	    	val = atoi(text);
+	    	val = strtoul(text,NULL,10);
 		sname = text;
 	    }
 	    else {
@@ -662,8 +663,16 @@ static int _handle_privmsg_command(t_connection * conn, int numparams, char ** p
 							text[strlen(text)-1] = '\0';
 							channel_message_send(channel,message_type_emote,conn,text);
 						} 
-						else
-							channel_message_send(channel,message_type_talk,conn,text);
+						else {
+                            if ((conn_get_wol(conn)==1) && (text[0] == '/')) {
+                                /* "/" commands (like "/help..." */
+                                handle_command(conn, text);
+                            }
+                            else {
+                                channel_message_log(channel, conn, 1, text);
+                                channel_message_send(channel,message_type_talk,conn,text);
+                            }
+						}
 					}
 					else {
 						irc_send(conn,ERR_NOSUCHCHANNEL,":No such channel");
@@ -706,7 +715,7 @@ static int _handle_notice_command(t_connection * conn, int numparams, char ** pa
 				t_connection * user;
 
 				if ((user = connlist_find_connection_by_accountname(e[i]))) {
-					irc_send_cmd2(user,conn_get_loggeduser(conn),"NOTICE",conn_get_loggeduser(user),text);
+				        message_send_text(user,message_type_notice,conn,text);
 				}
 				else {
 					irc_send(conn,ERR_NOSUCHNICK,":No such user");
@@ -778,7 +787,7 @@ static int _handle_list_command(t_connection * conn, int numparams, char ** para
 	    else if((strcmp(params[0], "18") == 0) ||
 				(strcmp(params[0], "21") == 0) ||
 				(strcmp(params[0], "33") == 0) ||
-				(strcmp(params[0], "41"))) {
+				(strcmp(params[0], "41") == 0)) {
     		eventlog(eventlog_level_debug,__FUNCTION__,"[** WOL **] LIST [Game]");
    			LIST_TRAVERSE_CONST(channellist(),curr) 
 			{
@@ -1155,10 +1164,10 @@ static int _handle_whois_command(t_connection * conn, int numparams, char ** par
 
 static int _handle_part_command(t_connection * conn, int numparams, char ** params, char * text)
 {
-    if ((conn_get_wol(conn) == 1))
-		if ((conn_wol_get_ingame(conn) == 1))
-			conn_wol_set_ingame(conn,0);
+    if ((conn_get_wol(conn) == 1) && (conn_wol_get_ingame(conn) == 1)) 
+        conn_wol_set_ingame(conn,0);
 
+    conn_set_channel(conn, NULL);
     message_send_text(conn,message_type_part,conn,NULL);
     return 0;
 }    
@@ -1191,11 +1200,20 @@ static int _handle_whereto_command(t_connection * conn, int numparams, char ** p
 	char temp[MAX_IRC_MESSAGE_LEN];
 
 	// Casted to avoid warnings
-	const char * ircip = addr_num_to_ip_str(conn_get_real_local_addr(conn));
+	const char * ircip;
 	const char * ircname = prefs_get_servername();
 	const char * irctimezone = prefs_get_wol_timezone();
 	const char * irclong = prefs_get_wol_longitude();
 	const char * irclat = prefs_get_wol_latitude();
+	
+    {			/* trans support */
+       unsigned short port = conn_get_real_local_port(conn);
+       unsigned int addr = conn_get_real_local_addr(conn);
+
+       trans_net(conn_get_addr(conn), &addr, &port);
+
+       ircip = addr_num_to_ip_str(addr);
+    }
 
 	sprintf(temp,":%s %d '0:%s' %s %s %s",ircip,BNETD_WOL_PORT,ircname,irctimezone,irclong,irclat);
 	irc_send(conn,RPL_IRCSERV,temp);
@@ -1353,7 +1371,26 @@ static int _handle_joingame_command(t_connection * conn, int numparams, char **
 	    if ((e)&&(e[0])) {
     		char const * ircname = irc_convert_ircname(e[0]);
     		char * old_channel_name = NULL;
+			t_channel * channel;
 	   	 	t_channel * old_channel = conn_get_channel(conn);
+	   	 	
+            channel = channellist_find_channel_by_name(ircname,NULL,NULL);
+
+            if (channel == NULL) {
+	   	 	     snprintf(_temp, sizeof(_temp), "%s :Game channel has closed",e[0]);
+	             irc_send(conn,ERR_GAMECHANCLOSED,_temp);
+			     if (e)
+		            irc_unget_listelems(e);
+     	         return 0;
+            }
+
+            if (channel_get_length(channel) == channel_get_max(channel)) {
+	   	 	     snprintf(_temp, sizeof(_temp), "%s :Channel is full",e[0]);
+                 irc_send(conn,ERR_CHANNELISFULL,_temp);
+			     if (e)
+		            irc_unget_listelems(e);
+			     return 0;
+            }
 
 			if (old_channel)
    	  		   old_channel_name = xstrdup(irc_convert_channel(old_channel));
@@ -1442,6 +1479,7 @@ static int _handle_joingame_command(t_connection * conn, int numparams, char **
 					channel_wol_set_game_owner(channel,conn_get_chatname(conn));
 					channel_wol_set_game_ownerip(channel,conn_get_addr(conn));
 					channel_wol_set_game_type(channel,conn_wol_get_game_type(conn));
+					channel_set_max(channel,atoi(params[2]));
 					channel_wol_set_game_tournament(channel,atoi(params[6]));
 					
 					message_send_text(conn,message_wol_joingame,conn,_temp); /* we have to send the JOINGAME acknowledgement */
