@@ -217,14 +217,15 @@ extern int irc_send_ping(t_connection * conn)
 	eventlog(eventlog_level_error,__FUNCTION__,"got NULL connection");
 	return -1;
     }
+
+    if((conn_get_wol(conn) == 1))
+        return 0;
+
     if (!(p = packet_create(packet_class_raw))) {
 	eventlog(eventlog_level_error,__FUNCTION__,"could not create packet");
 	return -1;
     }
 
-    if((conn_get_wol(conn) == 1))
-        return 0;
-
     conn_set_ircping(conn,get_ticks());
     if (conn_get_state(conn)==conn_state_bot_username)
     	sprintf(data,"PING :%u\r\n",conn_get_ircping(conn)); /* Undernet doesn't reveal the servername yet ... neither do we */
@@ -318,7 +319,7 @@ extern int irc_authenticate(t_connection * conn, char const * passhash)
     	    }
     	    
     	    if(tempapgar == NULL) {
-                irc_send_cmd(conn,"NOTICE",":Authentication failed."); /* bad APGAR */
+                irc_send(conn,RPL_BAD_LOGIN,":Authentication failed."); /* bad APGAR */
                 conn_increment_passfail_count(conn);
                 return 0;
             }
@@ -330,6 +331,7 @@ extern int irc_authenticate(t_connection * conn, char const * passhash)
         		return 1;
     	    }
     	    else {
+                       irc_send(conn,RPL_BAD_LOGIN,":Authentication failed."); /* bad APGAR */
         		conn_increment_passfail_count(conn);
         		return 0;
     	    }
@@ -896,7 +898,10 @@ extern int irc_message_format(t_packet * packet, t_message_type type, t_connecti
 	{
 	    char temp[MAX_IRC_MESSAGE_LEN];
 	    sprintf(temp,":%s",text);
-	    msg = irc_message_preformat(NULL,"NOTICE",NULL,temp);
+        if ((type==message_type_info || type==message_type_error) && (conn_get_wol(dst) == 1))
+            msg = irc_message_preformat(NULL,"PAGE",NULL,temp);
+        else
+	        msg = irc_message_preformat(NULL,"NOTICE",NULL,temp);
 	}
 	break;
     case message_type_channel:
@@ -909,6 +914,22 @@ extern int irc_message_format(t_packet * packet, t_message_type type, t_connecti
 	msg = irc_message_preformat(&from,"MODE","\r",text);
 	conn_unget_chatname(me,from.nick);
 	break;
+    case message_type_notice:
+         {
+	     char temp[MAX_IRC_MESSAGE_LEN];
+	     sprintf(temp,":%s",text);
+
+	     if (me && conn_get_chatname(me))
+	     {
+	         from.nick = conn_get_chatname(me);
+	         from.host = addr_num_to_ip_str(conn_get_addr(me));
+	         from.user = ctag;
+	         msg = irc_message_preformat(&from,"NOTICE","",temp);
+	     }else{
+	         msg = irc_message_preformat(NULL,"NOTICE","",temp);
+	     }
+	 }
+	 break;
    	/**
    	*  Westwood Online Extensions
    	*/
@@ -1008,13 +1029,9 @@ extern int irc_send_rpl_namreply(t_connection * c, t_channel const * channel)
 
     	    if((conn_get_wol(c) == 1))
     	    {
-        		if((conn_wol_get_ingame(c) == 0))
-        		{
-                    if ((flags & MF_BLIZZARD))
-        			   strcat(temp,"@");
-        		    if ((flags & MF_BNET) || (flags & MF_GAVEL))
-        			   strcat(temp,"@");
-        		}
+                if ((channel_wol_get_game_owner(channel) != NULL) && (strcmp(channel_wol_get_game_owner(channel),name) == 0)) {
+                            strcat(temp,"@");
+                    }
                 sprintf(temp,"%s%s,0,%u",temp,name,conn_get_addr(m));
     	    }
     	    else
