@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002,2003 Dizzy 
+ * Copyright (C) 2002,2003 Dizzy
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -45,6 +45,7 @@ static int sql_mysql_free_fields(t_sql_field *);
 static void sql_mysql_escape_string(char *, const char *, int);
 
 t_sql_engine sql_mysql = {
+    '`',
     sql_mysql_init,
     sql_mysql_close,
     sql_mysql_query_res,
@@ -67,7 +68,6 @@ static int sql_mysql_init(const char *host, const char *port, const char *socket
         eventlog(eventlog_level_error, __FUNCTION__, "got NULL parameter");
         return -1;
     }
-
     if ((mysql = mysql_init(NULL)) == NULL) {
         eventlog(eventlog_level_error, __FUNCTION__, "got error from mysql_init");
         return -1;
@@ -79,6 +79,23 @@ static int sql_mysql_init(const char *host, const char *port, const char *socket
         return -1;
     }
 
+#if MYSQL_VERSION_ID >= 50003
+  #if MYSQL_VERSION_ID >= 50013
+    my_bool my_true = (my_bool)1;
+    if (mysql_options(mysql, MYSQL_OPT_RECONNECT, &my_true)){
+      eventlog(eventlog_level_warn,__FUNCTION__,"Failed to turn on MYSQL_OPT_RECONNECT.");
+    }else{
+      eventlog(eventlog_level_info,__FUNCTION__,"Successfully turned on MYSQL_OPT_RECONNECT.");
+    }
+  #else
+    eventlog(eventlog_level_warn,__FUNCTION__,"Your mySQL client lib version does not support reconnecting after a timeout.");
+    eventlog(eventlog_level_warn,__FUNCTION__,"If this causes you any trouble you are advices to upgrade");
+    eventlog(eventlog_level_warn,__FUNCTION__,"your mySQL client libs to at least mySQL 5.0.13 to resolve this problem.");
+    // we might try a dirty hack like the following, but I'm not sure if it will work
+    // mysql->reconnect = 1;
+  #endif
+#endif
+
     return 0;
 }
 
