@@ -2,6 +2,7 @@
  * Copyright (C) 2000 Onlyer (onlyer@263.net)
  * Copyright (C) 2001 Ross Combs (ross@bnetd.org)
  * Copyright (C) 2002 Gianluigi Tiesi (sherpya@netfarm.it)
+ * Copyright (C) 2004 CreepLord (creeplord@pvpgn.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -54,6 +55,9 @@
 #  endif
 # endif
 #endif
+#ifdef HAVE_ASSERT_H
+# include <assert.h>
+#endif
 #include "compat/strchr.h"
 #include "compat/strdup.h"
 #include "compat/strcasecmp.h"
@@ -68,6 +72,8 @@
 #include "common/field_sizes.h"
 #include "prefs.h"
 #include "versioncheck.h"
+#include "common/tag.h"
+#include "common/xalloc.h"
 #include "common/setup_after.h"
 
 
@@ -76,47 +82,37 @@ static t_versioncheck dummyvc={ "A=42 B=42 C=42 4 A=A^S B=B^B C=C^C A=A^S", "IX8
 
 static int versioncheck_compare_exeinfo(t_parsed_exeinfo * pattern, t_parsed_exeinfo * match);
 
-extern t_versioncheck * versioncheck_create(char const * archtag, char const * clienttag)
+extern t_versioncheck * versioncheck_create(t_tag archtag, t_tag clienttag)
 {
     t_elem const *   curr;
     t_versioninfo *  vi;
     t_versioncheck * vc;
+    char             archtag_str[5];
+    char             clienttag_str[5];
     
     LIST_TRAVERSE_CONST(versioninfo_head,curr)
     {
         if (!(vi = elem_get_data(curr))) /* should not happen */
         {
-            eventlog(eventlog_level_error,"versioncheck_create","version list contains NULL item");
+            eventlog(eventlog_level_error,__FUNCTION__,"version list contains NULL item");
             continue;
         }
 	
-	eventlog(eventlog_level_debug,"versioncheck_create","version check entry archtag=%s, clienttag=%s",vi->archtag,vi->clienttag);
-	if (strcmp(vi->archtag,archtag)!=0)
+	eventlog(eventlog_level_debug,__FUNCTION__,"version check entry archtag=%s, clienttag=%s",
+	    tag_uint_to_str(archtag_str,vi->archtag),
+	    tag_uint_to_str(clienttag_str,vi->clienttag));
+	
+	if (vi->archtag != archtag)
 	    continue;
-	if (strcmp(vi->clienttag,clienttag)!=0)
+	if (vi->clienttag != clienttag)
 	    continue;
 	
 	/* FIXME: randomize the selection if more than one match */
-	if (!(vc = malloc(sizeof(t_versioncheck))))
-	{
-	    eventlog(eventlog_level_error,"versioncheck_create","unable to allocate memory for vc");
-	    return &dummyvc;
-	}
-	if (!(vc->eqn = strdup(vi->eqn)))
-	{
-	    eventlog(eventlog_level_error,"versioncheck_create","unable to allocate memory for eqn");
-	    free(vc);
-	    return &dummyvc;
-	}
-	if (!(vc->mpqfile = strdup(vi->mpqfile)))
-	{
-	    eventlog(eventlog_level_error,"versioncheck_create","unable to allocate memory for mpqfile");
-	    free((void *)vc->eqn); /* avoid warning */
-	    free(vc);
-	    return &dummyvc;
-	}
-	vc->versiontag = strdup(clienttag);
-	
+	vc = xmalloc(sizeof(t_versioncheck));
+	vc->eqn = xstrdup(vi->eqn);
+	vc->mpqfile = xstrdup(vi->mpqfile);
+	vc->versiontag = xstrdup(tag_uint_to_str(clienttag_str,clienttag));
+
 	return vc;
     }
     
@@ -133,17 +129,17 @@ extern int versioncheck_destroy(t_versioncheck * vc)
 {
     if (!vc)
     {
-	eventlog(eventlog_level_error,"versioncheck_destroy","got NULL vc");
+	eventlog(eventlog_level_error,__FUNCTION__,"got NULL vc");
 	return -1;
     }
     
     if (vc==&dummyvc)
 	return 0;
     
-    free((void *)vc->versiontag);
-    free((void *)vc->mpqfile);
-    free((void *)vc->eqn);
-    free(vc);
+    xfree((void *)vc->versiontag);
+    xfree((void *)vc->mpqfile);
+    xfree((void *)vc->eqn);
+    xfree(vc);
     
     return 0;
 }
@@ -151,16 +147,16 @@ extern int versioncheck_destroy(t_versioncheck * vc)
 extern int versioncheck_set_versiontag(t_versioncheck * vc, char const * versiontag)
 {
     if (!vc) {
-	eventlog(eventlog_level_error,"versioncheck_set_versiontag","got NULL vc");
+	eventlog(eventlog_level_error,__FUNCTION__,"got NULL vc");
 	return -1;
     }
     if (!versiontag) {
-	eventlog(eventlog_level_error,"versioncheck_set_versiontag","got NULL versiontag");
+	eventlog(eventlog_level_error,__FUNCTION__,"got NULL versiontag");
 	return -1;
     }
     
-    if (vc->versiontag!=NULL) free((void *)vc->versiontag);
-    vc->versiontag = strdup(versiontag);
+    if (vc->versiontag!=NULL) xfree((void *)vc->versiontag);
+    vc->versiontag = xstrdup(versiontag);
     return 0;
 }
 
@@ -168,7 +164,7 @@ extern int versioncheck_set_versiontag(t_versioncheck * vc, char const * version
 extern char const * versioncheck_get_versiontag(t_versioncheck const * vc)
 {
     if (!vc) {
-	eventlog(eventlog_level_error,"versioncheck_get_versiontag","got NULL vc");
+	eventlog(eventlog_level_error,__FUNCTION__,"got NULL vc");
 	return NULL;
     }
     
@@ -180,7 +176,7 @@ extern char const * versioncheck_get_mpqfile(t_versioncheck const * vc)
 {
     if (!vc)
     {
-	eventlog(eventlog_level_error,"versioncheck_get_mpqfile","got NULL vc");
+	eventlog(eventlog_level_error,__FUNCTION__,"got NULL vc");
 	return NULL;
     }
     
@@ -192,7 +188,7 @@ extern char const * versioncheck_get_eqn(t_versioncheck const * vc)
 {
     if (!vc)
     {
-	eventlog(eventlog_level_error,"versioncheck_get_mpqfile","got NULL vc");
+	eventlog(eventlog_level_error,__FUNCTION__,"got NULL vc");
 	return NULL;
     }
     
@@ -207,18 +203,8 @@ t_parsed_exeinfo * parse_exeinfo(char const * exeinfo)
 	return NULL;
     }
 
-    if (!(parsed_exeinfo = malloc(sizeof(t_parsed_exeinfo))))
-    {
-      eventlog(eventlog_level_error,__FUNCTION__,"could not allocate memory for parsed exeinfo");
-      return NULL;
-    }
-
-    if (!(parsed_exeinfo->exe = strdup(exeinfo)))
-    {
-      free((void *)parsed_exeinfo);
-      eventlog(eventlog_level_error,__FUNCTION__,"could not duplicate exeinfo");
-      return NULL;
-    }
+    parsed_exeinfo = xmalloc(sizeof(t_parsed_exeinfo));
+    parsed_exeinfo->exe = xstrdup(exeinfo);
     parsed_exeinfo->time = 0;
     parsed_exeinfo->size = 0;
     
@@ -235,8 +221,8 @@ t_parsed_exeinfo * parse_exeinfo(char const * exeinfo)
 	if ((exeinfo[0]=='\0') ||	   //happens when using war3-noCD and having deleted war3.org
 	    (strcmp(exeinfo,"badexe")==0)) //happens when AUTHREQ had no owner/exeinfo entry
 	{
-          free((void *)parsed_exeinfo->exe);
-          free((void *)parsed_exeinfo);
+          xfree((void *)parsed_exeinfo->exe);
+          xfree((void *)parsed_exeinfo);
           eventlog(eventlog_level_error,__FUNCTION__,"found empty exeinfo");
           return NULL;
 	}
@@ -247,24 +233,24 @@ t_parsed_exeinfo * parse_exeinfo(char const * exeinfo)
         exeinfo    = strreverse((char *)exeinfo);
         if (!(marker     = strchr(exeinfo,' ')))
         {
-	  free((void *)parsed_exeinfo->exe);
-	  free((void *)parsed_exeinfo);
+	  xfree((void *)parsed_exeinfo->exe);
+	  xfree((void *)parsed_exeinfo);
 	  return NULL;
         }
 	for (; marker[0]==' ';marker++); 
 
         if (!(marker     = strchr(marker,' ')))
         {
-	  free((void *)parsed_exeinfo->exe);
-	  free((void *)parsed_exeinfo);
+	  xfree((void *)parsed_exeinfo->exe);
+	  xfree((void *)parsed_exeinfo);
 	  return NULL;
 	} 
 	for (; marker[0]==' ';marker++);
 
         if (!(marker     = strchr(marker,' ')))
         {
-	  free((void *)parsed_exeinfo->exe);
-	  free((void *)parsed_exeinfo);
+	  xfree((void *)parsed_exeinfo->exe);
+	  xfree((void *)parsed_exeinfo);
 	  return NULL;
 	}
         for (; marker[0]==' ';marker++);
@@ -272,14 +258,8 @@ t_parsed_exeinfo * parse_exeinfo(char const * exeinfo)
         marker[0]  = '\0';
         marker++; 
         
-        if (!(exe = strdup(marker)))
-        {
-          free((void *)parsed_exeinfo->exe);
-          free((void *)parsed_exeinfo);
-          eventlog(eventlog_level_error,__FUNCTION__,"could not duplicate exe");
-          return NULL;
-        }
-        free((void *)parsed_exeinfo->exe);
+        exe = xstrdup(marker);
+        xfree((void *)parsed_exeinfo->exe);
         parsed_exeinfo->exe = strreverse((char *)exe);
 
         exeinfo    = strreverse((char *)exeinfo);
@@ -291,8 +271,8 @@ t_parsed_exeinfo * parse_exeinfo(char const * exeinfo)
             {
 
 	      eventlog(eventlog_level_warn,__FUNCTION__,"parser error while parsing pattern \"%s\"",exeinfo);
-	      free((void *)parsed_exeinfo->exe);
-	      free((void *)parsed_exeinfo);
+	      xfree((void *)parsed_exeinfo->exe);
+	      xfree((void *)parsed_exeinfo);
 	      return NULL; /* neq */
             }
             time_invalid=1;
@@ -329,14 +309,11 @@ t_parsed_exeinfo * parse_exeinfo(char const * exeinfo)
 //static int versioncheck_compare_exeinfo(char const * pattern, char const * match)
 static int versioncheck_compare_exeinfo(t_parsed_exeinfo * pattern, t_parsed_exeinfo * match)
 {
-    if (!pattern) {
-	eventlog(eventlog_level_error,"versioncheck_compare_exeinfo","got NULL pattern");
-	return -1; /* neq/fail */
-    }
-    if (!match) {
-	eventlog(eventlog_level_error,"versioncheck_compare_exeinfo","got NULL match");
-	return -1; /* neq/fail */
-    }
+    assert(pattern);
+    assert(match);
+
+    if (!strcasecmp(prefs_get_version_exeinfo_match(),"none"))
+	return 0;	/* ignore exeinfo */
 
     if (strlen(pattern->exe)!=strlen(match->exe))
     	return 1; /* neq */
@@ -365,14 +342,14 @@ static int versioncheck_compare_exeinfo(t_parsed_exeinfo * pattern, t_parsed_exe
             eventlog(eventlog_level_trace,__FUNCTION__,"size differs");
 	    return 1; /* neq */
             }
-	if ((pattern->time!=-1) && (abs(pattern->time-match->time)>(signed)prefs_get_version_exeinfo_maxdiff()))
+	if ((pattern->time!=-1) && prefs_get_version_exeinfo_maxdiff() && (abs(pattern->time-match->time)>(signed)prefs_get_version_exeinfo_maxdiff()))
             {
             eventlog(eventlog_level_trace,__FUNCTION__,"time differs by %i",abs(pattern->time-match->time));
 	    return 1;
             }
 	return 0; /* ok */
     } else {
-	eventlog(eventlog_level_error,"versioncheck_compare_exeinfo","unknown version exeinfo match method \"%s\"",prefs_get_version_exeinfo_match());
+	eventlog(eventlog_level_error,__FUNCTION__,"unknown version exeinfo match method \"%s\"",prefs_get_version_exeinfo_match());
 	return -1; /* neq/fail */
     }
 }
@@ -382,12 +359,12 @@ void free_parsed_exeinfo(t_parsed_exeinfo * parsed_exeinfo)
   if (parsed_exeinfo)
   {
     if (parsed_exeinfo->exe) 
-      free((void *)parsed_exeinfo->exe);
-    free((void *)parsed_exeinfo);
+      xfree((void *)parsed_exeinfo->exe);
+    xfree((void *)parsed_exeinfo);
   }
 }
 
-extern int versioncheck_validate(t_versioncheck * vc, char const * archtag, char const * clienttag, char const * exeinfo, unsigned long versionid, unsigned long gameversion, unsigned long checksum)
+extern int versioncheck_validate(t_versioncheck * vc, t_tag archtag, t_tag clienttag, char const * exeinfo, unsigned long versionid, unsigned long gameversion, unsigned long checksum)
 {
     t_elem const     * curr;
     t_versioninfo    * vi;
@@ -396,7 +373,7 @@ extern int versioncheck_validate(t_versioncheck * vc, char const * archtag, char
     
     if (!vc)
     {
-	eventlog(eventlog_level_error,"versioncheck_validate","got NULL vc");
+	eventlog(eventlog_level_error,__FUNCTION__,"got NULL vc");
 	return -1;
     }
     
@@ -406,18 +383,18 @@ extern int versioncheck_validate(t_versioncheck * vc, char const * archtag, char
     {
         if (!(vi = elem_get_data(curr))) /* should not happen */
         {
-	    eventlog(eventlog_level_error,"versioncheck_validate","version list contains NULL item");
+	    eventlog(eventlog_level_error,__FUNCTION__,"version list contains NULL item");
 	    continue;
         }
 	
+	if (vi->archtag != archtag)
+	    continue;
+	if (vi->clienttag != clienttag)
+	    continue;
 	if (strcmp(vi->eqn,vc->eqn)!=0)
 	    continue;
 	if (strcmp(vi->mpqfile,vc->mpqfile)!=0)
 	    continue;
-	if (strcmp(vi->archtag,archtag)!=0)
-	    continue;
-	if (strcmp(vi->clienttag,clienttag)!=0)
-	    continue;
 	
 	if (vi->versionid && vi->versionid != versionid)
 	    continue;
@@ -425,7 +402,7 @@ extern int versioncheck_validate(t_versioncheck * vc, char const * archtag, char
 	if (vi->gameversion && vi->gameversion != gameversion)
 	    continue;
 
-	
+
 	if ((!(parsed_exeinfo)) || (vi->parsed_exeinfo && (versioncheck_compare_exeinfo(vi->parsed_exeinfo,parsed_exeinfo) != 0)))
 	{
 	    /*
@@ -451,34 +428,34 @@ extern int versioncheck_validate(t_versioncheck * vc, char const * archtag, char
 	    badcs = 0;
 	
 	if (vc->versiontag)
-	    free((void *)vc->versiontag);
-	vc->versiontag = strdup(vi->versiontag);
+	    xfree((void *)vc->versiontag);
+	vc->versiontag = xstrdup(vi->versiontag);
 	
 	if (badexe || badcs)
 	    continue;
 	
 	/* Ok, version and checksum matches or exeinfo/checksum are disabled
 	 * anyway we have found a complete match */
-	eventlog(eventlog_level_info,"versioncheck_validate","got a matching entry: %s",vc->versiontag);
+	eventlog(eventlog_level_info,__FUNCTION__,"got a matching entry: %s",vc->versiontag);
         free_parsed_exeinfo(parsed_exeinfo);
 	return 1;
     }
     
     if (badcs) /* A match was found but the checksum was different */
     {
-	eventlog(eventlog_level_info,"versioncheck_validate","bad checksum, closest match is: %s",vc->versiontag);
+	eventlog(eventlog_level_info,__FUNCTION__,"bad checksum, closest match is: %s",vc->versiontag);
         free_parsed_exeinfo(parsed_exeinfo);
 	return -1;
     }
     if (badexe) /* A match was found but the exeinfo string was different */
     {
-	eventlog(eventlog_level_info,"versioncheck_validate","bad exeinfo, closest match is: %s",vc->versiontag);
+	eventlog(eventlog_level_info,__FUNCTION__,"bad exeinfo, closest match is: %s",vc->versiontag);
         free_parsed_exeinfo(parsed_exeinfo);
 	return -1;
     }
     
     /* No match in list */
-    eventlog(eventlog_level_info,"versioncheck_validate","no match in list, setting to: %s",vc->versiontag);
+    eventlog(eventlog_level_info,__FUNCTION__,"no match in list, setting to: %s",vc->versiontag);
     free_parsed_exeinfo(parsed_exeinfo);
     return 0;
 }
@@ -503,18 +480,18 @@ extern int versioncheck_load(char const * filename)
     
     if (!filename)
     {
-	eventlog(eventlog_level_error,"versioncheck_load","got NULL filename");
+	eventlog(eventlog_level_error,__FUNCTION__,"got NULL filename");
 	return -1;
     }
     
     if (!(versioninfo_head = list_create()))
     {
-	eventlog(eventlog_level_error,"versioncheck_load","could create list");
+	eventlog(eventlog_level_error,__FUNCTION__,"could create list");
 	return -1;
     }
     if (!(fp = fopen(filename,"r")))
     {
-	eventlog(eventlog_level_error,"versioncheck_load","could not open file \"%s\" for reading (fopen: %s)",filename,strerror(errno));
+	eventlog(eventlog_level_error,__FUNCTION__,"could not open file \"%s\" for reading (fopen: %s)",filename,pstrerror(errno));
 	list_destroy(versioninfo_head);
 	versioninfo_head = NULL;
 	return -1;
@@ -526,7 +503,6 @@ extern int versioncheck_load(char const * filename)
 	for (pos=0; buff[pos]=='\t' || buff[pos]==' '; pos++);
 	if (buff[pos]=='\0' || buff[pos]=='#')
 	{
-	    free(buff);
 	    continue;
 	}
 	if ((temp = strrchr(buff,'#')))
@@ -542,57 +518,49 @@ extern int versioncheck_load(char const * filename)
 
 	if (!(eqn = next_token(buff,&pos)))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","missing eqn near line %u of file \"%s\"",line,filename);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"missing eqn near line %u of file \"%s\"",line,filename);
 	    continue;
 	}
 	line++;
 	if (!(mpqfile = next_token(buff,&pos)))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","missing mpqfile near line %u of file \"%s\"",line,filename);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"missing mpqfile near line %u of file \"%s\"",line,filename);
 	    continue;
 	}
 	line++;
 	if (!(archtag = next_token(buff,&pos)))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","missing archtag near line %u of file \"%s\"",line,filename);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"missing archtag near line %u of file \"%s\"",line,filename);
 	    continue;
 	}
 	line++;
 	if (!(clienttag = next_token(buff,&pos)))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","missing clienttag near line %u of file \"%s\"",line,filename);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"missing clienttag near line %u of file \"%s\"",line,filename);
 	    continue;
 	}
 	line++;
 	if (!(exeinfo = next_token(buff,&pos)))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","missing exeinfo near line %u of file \"%s\"",line,filename);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"missing exeinfo near line %u of file \"%s\"",line,filename);
 	    continue;
 	}
 	line++;
 	if (!(versionid = next_token(buff,&pos)))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","missing versionid near line %u of file \"%s\"",line,filename);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"missing versionid near line %u of file \"%s\"",line,filename);
 	    continue;
 	}
 	line++;
 	if (!(gameversion = next_token(buff,&pos)))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","missing gameversion near line %u of file \"%s\"",line,filename);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"missing gameversion near line %u of file \"%s\"",line,filename);
 	    continue;
 	}
 	line++;
 	if (!(checksum = next_token(buff,&pos)))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","missing checksum near line %u of file \"%s\"",line,filename);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"missing checksum near line %u of file \"%s\"",line,filename);
 	    continue;
 	}
 	line++;
@@ -600,64 +568,40 @@ extern int versioncheck_load(char const * filename)
 	{
 	    versiontag = NULL;
 	}
-	
-	if (!(vi = malloc(sizeof(t_versioninfo))))
-	{
-	    eventlog(eventlog_level_error,"versioncheck_load","could not allocate memory for vi");
-	    free(buff);
-	    continue;
-	}
-	if (!(vi->eqn = strdup(eqn)))
-	{
-	    eventlog(eventlog_level_error,"versioncheck_load","could not allocate memory for eqn");
-	    free(vi);
-	    free(buff);
-	    continue;
-	}
-	if (!(vi->mpqfile = strdup(mpqfile)))
-	{
-	    eventlog(eventlog_level_error,"versioncheck_load","could not allocate memory for mpqfile");
-	    free((void *)vi->eqn); /* avoid warning */
-	    free(vi);
-	    free(buff);
-	    continue;
-	}
+
+	vi = xmalloc(sizeof(t_versioninfo));
+	vi->eqn = xstrdup(eqn);
+	vi->mpqfile = xstrdup(mpqfile);
 	if (strlen(archtag)!=4)
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","invalid arch tag on line %u of file \"%s\"",line,filename);
-	    free((void *)vi->mpqfile); /* avoid warning */
-	    free((void *)vi->eqn); /* avoid warning */
-	    free(vi);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"invalid arch tag on line %u of file \"%s\"",line,filename);
+	    xfree((void *)vi->mpqfile); /* avoid warning */
+	    xfree((void *)vi->eqn); /* avoid warning */
+	    xfree(vi);
 	    continue;
 	}
-	if (!(vi->archtag = strdup(archtag)))
+	if (!tag_check_arch((vi->archtag = tag_str_to_uint(archtag))))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","could not allocate memory for archtag");
-	    free((void *)vi->mpqfile); /* avoid warning */
-	    free((void *)vi->eqn); /* avoid warning */
-	    free(vi);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"got unknown archtag \"%s\"",archtag);
+	    xfree((void *)vi->mpqfile); /* avoid warning */
+	    xfree((void *)vi->eqn); /* avoid warning */
+	    xfree(vi);
 	    continue;
 	}
 	if (strlen(clienttag)!=4)
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","invalid client tag on line %u of file \"%s\"",line,filename);
-	    free((void *)vi->archtag); /* avoid warning */
-	    free((void *)vi->mpqfile); /* avoid warning */
-	    free((void *)vi->eqn); /* avoid warning */
-	    free(vi);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"invalid client tag on line %u of file \"%s\"",line,filename);
+	    xfree((void *)vi->mpqfile); /* avoid warning */
+	    xfree((void *)vi->eqn); /* avoid warning */
+	    xfree(vi);
 	    continue;
 	}
-	if (!(vi->clienttag = strdup(clienttag)))
+	if (!tag_check_client((vi->clienttag = tag_str_to_uint(clienttag))))
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","could not allocate memory for clienttag");
-	    free((void *)vi->archtag); /* avoid warning */
-	    free((void *)vi->mpqfile); /* avoid warning */
-	    free((void *)vi->eqn); /* avoid warning */
-	    free(vi);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"got unknown clienttag\"%s\"",clienttag);
+	    xfree((void *)vi->mpqfile); /* avoid warning */
+	    xfree((void *)vi->eqn); /* avoid warning */
+	    xfree(vi);
 	    continue;
 	}
 	if (strcmp(exeinfo, "NULL") == 0)
@@ -666,13 +610,10 @@ extern int versioncheck_load(char const * filename)
 	{
 	    if (!(vi->parsed_exeinfo = parse_exeinfo(exeinfo)))
 	    {
-		eventlog(eventlog_level_error,"versioncheck_load","encountered an error while parsing exeinfo");
-		free((void *)vi->clienttag); /* avoid warning */
-		free((void *)vi->archtag); /* avoid warning */
-		free((void *)vi->mpqfile); /* avoid warning */
-		free((void *)vi->eqn); /* avoid warning */
-		free(vi);
-		free(buff);
+		eventlog(eventlog_level_error,__FUNCTION__,"encountered an error while parsing exeinfo");
+		xfree((void *)vi->mpqfile); /* avoid warning */
+		xfree((void *)vi->eqn); /* avoid warning */
+		xfree(vi);
 		continue;
 	    }
 	}
@@ -680,55 +621,27 @@ extern int versioncheck_load(char const * filename)
 	vi->versionid = strtoul(versionid,NULL,0);
 	if (verstr_to_vernum(gameversion,&vi->gameversion)<0)
 	{
-	    eventlog(eventlog_level_error,"versioncheck_load","malformed version on line %u of file \"%s\"",line,filename);
-	    free((void *)vi->parsed_exeinfo); /* avoid warning */
-	    free((void *)vi->clienttag); /* avoid warning */
-	    free((void *)vi->archtag); /* avoid warning */
-	    free((void *)vi->mpqfile); /* avoid warning */
-	    free((void *)vi->eqn); /* avoid warning */
-	    free(vi);
-	    free(buff);
+	    eventlog(eventlog_level_error,__FUNCTION__,"malformed version on line %u of file \"%s\"",line,filename);
+	    xfree((void *)vi->parsed_exeinfo); /* avoid warning */
+	    xfree((void *)vi->mpqfile); /* avoid warning */
+	    xfree((void *)vi->eqn); /* avoid warning */
+	    xfree(vi);
 	    continue;
         }
 
 	vi->checksum = strtoul(checksum,NULL,0);
 	if (versiontag)
-	{
-	    if (!(vi->versiontag = strdup(versiontag)))
-	    {
-		eventlog(eventlog_level_error,"versioncheck_load","could not allocate memory for versiontag");
-		free((void *)vi->parsed_exeinfo); /* avoid warning */
-		free((void *)vi->clienttag); /* avoid warning */
-		free((void *)vi->archtag); /* avoid warning */
-		free((void *)vi->mpqfile); /* avoid warning */
-		free((void *)vi->eqn); /* avoid warning */
-		free(vi);
-		free(buff);
-		continue;
-	    }
-	}
+	    vi->versiontag = xstrdup(versiontag);
 	else
 	    vi->versiontag = NULL;
 	
-	free(buff);
 	
-	if (list_append_data(versioninfo_head,vi)<0)
-	{
-	    eventlog(eventlog_level_error,"versioncheck_load","could not append item");
-	    if (vi->versiontag)
-	      free((void *)vi->versiontag); /* avoid warning */
-	    free((void *)vi->parsed_exeinfo); /* avoid warning */
-	    free((void *)vi->clienttag); /* avoid warning */
-	    free((void *)vi->archtag); /* avoid warning */
-	    free((void *)vi->mpqfile); /* avoid warning */
-	    free((void *)vi->eqn); /* avoid warning */
-	    free(vi);
-	    continue;
-	}
+	list_append_data(versioninfo_head,vi);
     }
     
+    file_get_line(NULL); // clear file_get_line buffer
     if (fclose(fp)<0)
-	eventlog(eventlog_level_error,"versioncheck_load","could not close versioncheck file \"%s\" after reading (fclose: %s)",filename,strerror(errno));
+	eventlog(eventlog_level_error,__FUNCTION__,"could not close versioncheck file \"%s\" after reading (fclose: %s)",filename,pstrerror(errno));
     
     return 0;
 }
@@ -745,26 +658,24 @@ extern int versioncheck_unload(void)
 	{
 	    if (!(vi = elem_get_data(curr))) /* should not happen */
 	    {
-		eventlog(eventlog_level_error,"versioncheck_unload","version list contains NULL item");
+		eventlog(eventlog_level_error,__FUNCTION__,"version list contains NULL item");
 		continue;
 	    }
 	    
-	    if (list_remove_elem(versioninfo_head,curr)<0)
-		eventlog(eventlog_level_error,"versioncheck_unload","could not remove item from list");
+	    if (list_remove_elem(versioninfo_head,&curr)<0)
+		eventlog(eventlog_level_error,__FUNCTION__,"could not remove item from list");
 
 	    if (vi->parsed_exeinfo)
             {
                 if (vi->parsed_exeinfo->exe)
-                    free((void *)vi->parsed_exeinfo->exe);
-		free((void *)vi->parsed_exeinfo); /* avoid warning */
+                    xfree((void *)vi->parsed_exeinfo->exe);
+		xfree((void *)vi->parsed_exeinfo); /* avoid warning */
             }
-	    free((void *)vi->clienttag); /* avoid warning */
-	    free((void *)vi->archtag); /* avoid warning */
-	    free((void *)vi->mpqfile); /* avoid warning */
-	    free((void *)vi->eqn); /* avoid warning */
+	    xfree((void *)vi->mpqfile); /* avoid warning */
+	    xfree((void *)vi->eqn); /* avoid warning */
 	    if (vi->versiontag)
-		free((void *)vi->versiontag); /* avoid warning */
-	    free(vi);
+		xfree((void *)vi->versiontag); /* avoid warning */
+	    xfree(vi);
 	}
 	
 	if (list_destroy(versioninfo_head)<0)
@@ -774,4 +685,3 @@ extern int versioncheck_unload(void)
     
     return 0;
 }
-
