@@ -43,11 +43,11 @@
 #define CLIENT_EXEINFO_DRTL     "Diablo.exe 05/18/01 23:10:57 767760"
 #define CLIENT_CHECKSUM_DRTL    0xac337ef9
 
-//plain Starcraft 1.11b
-#define CLIENT_VERSIONID_STAR   0x000000c9
-#define CLIENT_GAMEVERSION_STAR 0x01010103
-#define CLIENT_EXEINFO_STAR     "starcraft.exe 05/26/04 00:46:00 1048576"
-#define CLIENT_CHECKSUM_STAR    0xe6380bff
+//plain Starcraft 1.13f
+#define CLIENT_VERSIONID_STAR   0x000000cd
+#define CLIENT_GAMEVERSION_STAR 0x0101030a
+#define CLIENT_EXEINFO_STAR     "starcraft.exe 01/13/06 05:46:36 1146939"
+#define CLIENT_CHECKSUM_STAR    0xcddd4cf8
 
 
 #define CLIENT_VERSIONID_SSHR   0x000000a5 /* FIXME: wrong? */
@@ -55,11 +55,11 @@
 #define CLIENT_EXEINFO_SSHR     "starcraft.exe 03/08/99 22:41:50 1042432" /* FIXME: wrong */
 #define CLIENT_CHECKSUM_SSHR    0x12345678
 
-//Broodwar 1.11b
-#define CLIENT_VERSIONID_SEXP   0x000000c9
-#define CLIENT_GAMEVERSION_SEXP 0x01010103
-#define CLIENT_EXEINFO_SEXP     "starcraft.exe 05/26/04 00:46:00 1048576"
-#define CLIENT_CHECKSUM_SEXP    0xe6380bff
+//Broodwar 1.13f
+#define CLIENT_VERSIONID_SEXP   0x000000cd
+#define CLIENT_GAMEVERSION_SEXP 0x0101030b
+#define CLIENT_EXEINFO_SEXP     "starcraft.exe 01/13/06 05:42:48 1146939"
+#define CLIENT_CHECKSUM_SEXP    0x8fed1d6d
 
 //Warcraft 2 Battle.Net Edition 2.02b
 #define CLIENT_VERSIONID_W2BN   0x0000004f
@@ -79,11 +79,11 @@
 #define CLIENT_EXEINFO_D2XP     "Game.exe 10/13/03 08:35:30 1198857"
 #define CLIENT_CHECKSUM_D2XP    0x210126ec
 
-//Warcraft 3 1.16 and Warcraft 3 Frozen Throne 1.16
-#define CLIENT_VERSIONID_WAR3   0x00000010
-#define CLIENT_GAMEVERSION_WAR3 0x01001026
-#define CLIENT_EXEINFO_WAR3     "war3.exe 06/28/04 23:37:02 1568211"
-#define CLIENT_CHECKSUM_WAR3    0xcc882269
+//Warcraft 3 1.16 and Warcraft 3 Frozen Throne 1.20e
+#define CLIENT_VERSIONID_WAR3   0x00000014
+#define CLIENT_GAMEVERSION_WAR3 0x0114047e
+#define CLIENT_EXEINFO_WAR3     "war3.exe 06/13/06 06:13:05 1572307"
+#define CLIENT_CHECKSUM_WAR3    0x8771b225
 
 #define CLIENT_COUNTRYINFO_109_PROTOCOL            0x00000000
 #define CLIENT_COUNTRYINFO_109_VERSIONID_D2DV      0x00000009
