@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 1998  Mark Baysinger (mbaysing@ucsd.edu)
+ * Copyright (C) 1998,1999,2000  Ross Combs (rocombs@cs.nmsu.edu)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ */
 #ifndef INCLUDED_ANONGAME_PROTOCOL_TYPES
 #define INCLUDED_ANONGAME_PROTOCOL_TYPES
 
@@ -18,7 +36,7 @@ typedef struct
     t_bnet_header	h;
     bn_byte		option;
     /* rest of packet data */
-} t_client_anongame PACKED_ATTR();
+} PACKED_ATTR() t_client_anongame;
 
 /***********************************************************************************/
 #define CLIENT_FINDANONGAME_SEARCH              0x00
@@ -28,6 +46,7 @@ typedef struct
 #define CLIENT_FINDANONGAME_AT_SEARCH           0x05
 #define CLIENT_FINDANONGAME_AT_INVITER_SEARCH   0x06
 #define CLIENT_ANONGAME_TOURNAMENT		0X07
+#define	CLIENT_FINDANONGAME_PROFILE_CLAN	0x08
 #define CLIENT_FINDANONGAME_GET_ICON            0x09
 #define CLIENT_FINDANONGAME_SET_ICON            0x0A
 
@@ -109,7 +128,7 @@ typedef struct
     bn_byte		unknown3;  /* 8 */
     bn_int		id;        /* client id */
     bn_int       	race;      /* 1 = H , 2 = O , 4 = N , 8 = U , 0x20 = R */
-} t_client_findanongame PACKED_ATTR();
+} PACKED_ATTR() t_client_findanongame;
 
 typedef struct
 {
@@ -127,7 +146,7 @@ typedef struct
     bn_byte      unknown3;  /* 08 */
     bn_int       id;	    /* client id */
     bn_int       race;      /* 1 = H , 2 = O , 4 = N , 8 = U , 0x20 = R */
-} t_client_findanongame_at_inv PACKED_ATTR();
+} PACKED_ATTR() t_client_findanongame_at_inv;
 
 typedef struct
 {
@@ -142,7 +161,7 @@ typedef struct
     bn_byte      unknown3;  /* 08 */
     bn_int       id;        /* client id */
     bn_int       race;      /* 1 = H , 2 = O , 4 = N , 8 = U , 0x20 = R */
-} t_client_findanongame_at PACKED_ATTR();
+} PACKED_ATTR() t_client_findanongame_at;
 
 #define SERVER_ANONGAME_SEARCH_REPLY		0x44ff
 typedef struct
@@ -152,7 +171,7 @@ typedef struct
     bn_int    count;
     bn_int    reply;
     /*      bn_short  avgtime; - only in W3XP so far average time in seconds of search */
-} t_server_anongame_search_reply PACKED_ATTR();
+} PACKED_ATTR() t_server_anongame_search_reply;
 
 /***********************************************************************************/
 /* option 01 - anongame found */
@@ -244,7 +263,7 @@ typedef struct
 				     */
     /* char *		mapname */
     /* t_saf_pt2 * 	pt2 */
-} t_server_anongame_found PACKED_ATTR();
+} PACKED_ATTR() t_server_anongame_found;
 
 /* MISC PACKET APPEND DATA's */
 typedef struct
@@ -256,7 +275,7 @@ typedef struct
     bn_short	unknown2;		/* 0x0000 */
     bn_byte	visibility;		/* 0x01 = dark - 0x02 = default */
     bn_byte	unknown3;		/* 0x02 */
-} t_saf_pt2 PACKED_ATTR();
+} PACKED_ATTR() t_saf_pt2;
 
 /***********************************************************************************/
 /* option 02 - info request */
@@ -268,7 +287,7 @@ typedef struct
 					 * 0x02 for matchmaking infos */
     bn_int              count;          /* 0x00000001 increments each request of same type */
     bn_byte             noitems;
-} t_client_findanongame_inforeq PACKED_ATTR();
+} PACKED_ATTR() t_client_findanongame_inforeq;
 
 #define SERVER_FINDANONGAME_INFOREPLY           0x44ff
 typedef struct {
@@ -286,17 +305,17 @@ for type 0x02 :
 	TYPE  : <info> unknown 38 bytes probably meaning anongame types
 	DESC  : <info>
 */
-} t_server_findanongame_inforeply PACKED_ATTR();
+} PACKED_ATTR() t_server_findanongame_inforeply;
 
 /***********************************************************************************/
 /* option 03 - playgame cancel */
 #define SERVER_FINDANONGAME_PLAYGAME_CANCEL 	0x44ff
 typedef struct
 {
-    t_bnet_header h; // header
-    bn_byte cancel; // Cancel byte always 03
+    t_bnet_header h; /* header */
+    bn_byte cancel; /* Cancel byte always 03 */
     bn_int  count;
-} t_server_findanongame_playgame_cancel PACKED_ATTR();
+} PACKED_ATTR() t_server_findanongame_playgame_cancel;
 
 
 /* option 04 - profile request */
@@ -305,9 +324,9 @@ typedef struct
     t_bnet_header h;
     bn_byte     option;
     bn_int          count;
-    // USERNAME TO LOOKUP //
-    // CLIENT TAG //
-} t_client_findanongame_profile PACKED_ATTR();
+    /* USERNAME TO LOOKUP
+     * CLIENT TAG */
+} PACKED_ATTR() t_client_findanongame_profile;
 
 #define SERVER_FINDANONGAME_PROFILE		0x44ff
 /*
@@ -318,7 +337,7 @@ typedef struct
     bn_int count; // count that goes up each time user clicks on someones profile
     // REST OF PROFILE STATS - THIS WILL BE SET IN HANDLE_BNET.C after
     // SERVER LOOKS UP THE USER ACCOUNT
-} t_server_findanongame_profile PACKED_ATTR();
+} PACKED_ATTR() t_server_findanongame_profile;
 */
 typedef struct
 {
@@ -327,9 +346,9 @@ typedef struct
     bn_int		count;
     bn_int		icon;
     bn_byte		rescount;
-    // REST OF PROFILE STATS - THIS WILL BE SET IN HANDLE_BNET.C after
-    // SERVER LOOKS UP THE USER ACCOUNT
-} t_server_findanongame_profile2 PACKED_ATTR();
+    /* REST OF PROFILE STATS - THIS WILL BE SET IN HANDLE_BNET.C after
+     * SERVER LOOKS UP THE USER ACCOUNT */
+} PACKED_ATTR() t_server_findanongame_profile2;
 
 /***********************************************************************************/
 /* option 07 - tournament request */
@@ -339,7 +358,7 @@ typedef struct
     t_bnet_header       h;
     bn_byte             option; /* 07 */
     bn_int              count;  /* 01 00 00 00 */
-} t_client_anongame_tournament_request PACKED_ATTR();
+} PACKED_ATTR() t_client_anongame_tournament_request;
 
 #define SERVER_FINDANONGAME_TOURNAMENT_REPLY    0x44ff
 typedef struct
@@ -365,7 +384,32 @@ typedef struct
     bn_byte             selection;  /* matches anongame_TY_section of DESC */
     bn_byte             descnum;    /* matches desc_count of DESC */
     bn_byte             nulltag;    /* 00 */
-} t_server_anongame_tournament_reply PACKED_ATTR();
+} PACKED_ATTR() t_server_anongame_tournament_reply;
+
+/***********************************************************************************/
+
+/* option 08 - clan profile request */
+typedef struct
+{
+    t_bnet_header h;
+    bn_byte	option;
+    bn_int	count;
+    bn_int	clantag;
+    bn_int	clienttag;
+} PACKED_ATTR() t_client_findanongame_profile_clan;
+
+#define SERVER_FINDANONGAME_PROFILE_CLAN	0x44ff
+
+typedef struct
+{
+    t_bnet_header	h;
+    bn_byte		option;
+    bn_int		count;
+    bn_byte		rescount;
+    /* REST OF PROFILE STATS - THIS WILL BE SET IN HANDLE_BNET.C after
+     * SERVER LOOKS UP THE USER ACCOUNT */
+} PACKED_ATTR() t_server_findanongame_profile_clan;
+
 
 /***********************************************************************************/
 /* option 9 - icon request */
@@ -378,7 +422,7 @@ typedef struct{
     bn_byte               table_width;            /* the icon table width */
     bn_byte               table_size;             /* the icon table total size */
     /* table data */
-} t_server_findanongame_iconreply PACKED_ATTR();
+} PACKED_ATTR() t_server_findanongame_iconreply;
 
 /***********************************************************************************/
 #define SERVER_ANONGAME_SOLO_STR        	0x534F4C4F /* "SOLO" */
@@ -389,14 +433,14 @@ typedef struct{
 #define SERVER_ANONGAME_AT4v4_STR       	0x34565334 /* "4VS4" */
 #define SERVER_ANONGAME_TY_STR			0X54592020 /* "TY  " FIXME-TY: WHAT TO PUT HERE */
 
-#define CLIENT_FINDANONGAME_INFOTAG_URL         0x55524c        //  URL\0
-#define CLIENT_FINDANONGAME_INFOTAG_MAP         0x4d4150        //  MAP\0
-#define CLIENT_FINDANONGAME_INFOTAG_TYPE        0x54595045      //  TYPE
-#define CLIENT_FINDANONGAME_INFOTAG_DESC        0x44455343      //  DESC
-#define CLIENT_FINDANONGAME_INFOTAG_LADR        0x4c414452      //  LADR
-#define CLIENT_FINDANONGAME_INFOTAG_SOLO        0x534f4c4f      //  SOLO
-#define CLIENT_FINDANONGAME_INFOTAG_TEAM        0x5445414d      //  TEAM
-#define CLIENT_FINDANONGAME_INFOTAG_FFA         0x46464120      //  FFA\20
+#define CLIENT_FINDANONGAME_INFOTAG_URL         0x55524c        /*  URL\0 */
+#define CLIENT_FINDANONGAME_INFOTAG_MAP         0x4d4150        /*  MAP\0 */
+#define CLIENT_FINDANONGAME_INFOTAG_TYPE        0x54595045      /*  TYPE */
+#define CLIENT_FINDANONGAME_INFOTAG_DESC        0x44455343      /*  DESC */
+#define CLIENT_FINDANONGAME_INFOTAG_LADR        0x4c414452      /*  LADR */
+#define CLIENT_FINDANONGAME_INFOTAG_SOLO        0x534f4c4f      /*  SOLO */
+#define CLIENT_FINDANONGAME_INFOTAG_TEAM        0x5445414d      /*  TEAM */
+#define CLIENT_FINDANONGAME_INFOTAG_FFA         0x46464120      /*  FFA\20 */
 
 #define ANONGAME_TYPE_1V1       0
 #define ANONGAME_TYPE_2V2       1
@@ -420,7 +464,7 @@ typedef struct{
 
 #define ANONGAME_TYPES 18
 
-#define SERVER_FINDANONGAME_PROFILE_UNKNOWN2    0x6E736865 //Sheep
+#define SERVER_FINDANONGAME_PROFILE_UNKNOWN2    0x6E736865 /* Sheep */
 
 /***********************************************************************************/
 /***********************************************************************************/
@@ -429,7 +473,7 @@ typedef struct{
 typedef struct
 {
 	t_bnet_header h;
-} t_client_arrangedteam_friendscreen PACKED_ATTR();
+} PACKED_ATTR() t_client_arrangedteam_friendscreen;
 
 /***********************************************************************************/
 #define SERVER_ARRANGEDTEAM_FRIENDSCREEN 0x60ff
@@ -438,7 +482,7 @@ typedef struct
 	t_bnet_header h;
 	bn_byte f_count;
 	/* usernames get appended here */
-} t_server_arrangedteam_friendscreen PACKED_ATTR();
+} PACKED_ATTR() t_server_arrangedteam_friendscreen;
 
 #define SERVER_ARRANGED_TEAM_ADDNAME 0x01 
 
@@ -454,9 +498,9 @@ typedef struct
 	bn_int		count;
 	bn_int		id;
 	bn_int		unknown1;	/* 01 00 00 00 */
-	bn_byte 	numfriends;	//next is a byte, that is the number of friends to invite
+	bn_byte 	numfriends;	/* next is a byte, that is the number of friends to invite */
 	/* usernames get appended here */
-} t_client_arrangedteam_invite_friend PACKED_ATTR();
+} PACKED_ATTR() t_client_arrangedteam_invite_friend;
 
 /***********************************************************************************/
 #define SERVER_ARRANGEDTEAM_INVITE_FRIEND_ACK 0x61ff
@@ -468,7 +512,7 @@ typedef struct
         bn_int		timestamp;
         bn_byte 	teamsize;    /* numfriends + 1 */
         bn_int		info[5];
-} t_server_arrangedteam_invite_friend_ack PACKED_ATTR();
+} PACKED_ATTR() t_server_arrangedteam_invite_friend_ack;
 
 /***********************************************************************************/
 #define SERVER_ARRANGEDTEAM_SEND_INVITE 0x63ff
@@ -482,7 +526,7 @@ typedef struct
 	bn_byte numfriends; /* Number of friends that got invited to the game */
 	/* username of the inviter */
 	/* usernames of the others who got invited */
-} t_server_arrangedteam_send_invite PACKED_ATTR();
+} PACKED_ATTR() t_server_arrangedteam_send_invite;
 
 /***********************************************************************************/
 #define CLIENT_ARRANGEDTEAM_ACCEPT_DECLINE_INVITE 0x63ff
@@ -493,7 +537,7 @@ typedef struct
 	bn_int id;
 	bn_int option;   /* accept or decline */
 	/* username of the inviter */
-} t_client_arrangedteam_accept_decline_invite PACKED_ATTR();
+} PACKED_ATTR() t_client_arrangedteam_accept_decline_invite;
 
 #define CLIENT_ARRANGEDTEAM_ACCEPT		0x00000003
 #define CLIENT_ARRANGEDTEAM_DECLINE		0x00000002
@@ -504,9 +548,9 @@ typedef struct
 {
 	t_bnet_header h;
 	bn_int count;
-	bn_int action; // number assigned to player? playernum?
-	//username of the person who declined invitation
-} t_server_arrangedteam_member_decline PACKED_ATTR();
+	bn_int action; /* number assigned to player? playernum? */
+	/* username of the person who declined invitation */
+} PACKED_ATTR() t_server_arrangedteam_member_decline;
 
 #define SERVER_ARRANGEDTEAM_ACCEPT		0x00000003
 #define SERVER_ARRANGEDTEAM_DECLINE		0x00000002
@@ -535,7 +579,7 @@ typedef struct
 typedef struct
 {
     t_bnet_header h;
-} t_client_friendslistreq PACKED_ATTR();
+} PACKED_ATTR() t_client_friendslistreq;
     
 /*
 # 158 packet from server: type=0x65ff(unknown) length=16 class=bnet
@@ -549,14 +593,14 @@ typedef struct
     t_bnet_header h;
     bn_byte friendcount;
     /* 1 byte status, 0-terminated name, 6 bytes unknown, ... */
-} t_server_friendslistreply PACKED_ATTR();
+} PACKED_ATTR() t_server_friendslistreply;
 
 typedef struct
 {
     bn_byte status;
     bn_byte location;
     bn_int clienttag;
-} t_server_friendslistreply_status PACKED_ATTR();
+} PACKED_ATTR() t_server_friendslistreply_status;
 	
 /*
 # 124 packet from client: type=0x66ff(unknown) length=5 class=bnet
@@ -568,7 +612,7 @@ typedef struct
 {
     t_bnet_header h;
     bn_byte friendnum;
-} t_client_friendinforeq PACKED_ATTR();
+} PACKED_ATTR() t_client_friendinforeq;
 
 /*
 # 126 packet from server: type=0x66ff(unknown) length=12 class=bnet
@@ -591,7 +635,7 @@ typedef struct
     bn_byte status;
     bn_int clienttag;
     /* game name */
-} t_server_friendinforeply PACKED_ATTR();
+} PACKED_ATTR() t_server_friendinforeply;
 #define FRIEND_TYPE_NON_MUTUAL 0x00
 #define FRIEND_TYPE_MUTUAL     0x01
 #define FRIEND_TYPE_DND	       0x02
@@ -607,7 +651,7 @@ typedef struct
 {
     t_bnet_header h;
     /* friend name, status */
-} t_server_friendadd_ack PACKED_ATTR();
+} PACKED_ATTR() t_server_friendadd_ack;
 /******************************************************/
 /*
 # 114 packet from server: type=0x68ff(unknown) length=5 class=bnet
@@ -618,7 +662,7 @@ typedef struct
 {
     t_bnet_header h;
     bn_byte friendnum;
-} t_server_frienddel_ack PACKED_ATTR();
+} PACKED_ATTR() t_server_frienddel_ack;
 /******************************************************/
 
 #define SERVER_FRIENDMOVE_ACK 0x69ff
@@ -627,7 +671,7 @@ typedef struct
     t_bnet_header h;
     bn_byte pos1;
     bn_byte pos2;
-} t_server_friendmove_ack PACKED_ATTR();
+} PACKED_ATTR() t_server_friendmove_ack;
 
 #define FRIENDSTATUS_OFFLINE    	0x00
 #define FRIENDSTATUS_ONLINE     	0x01
