@@ -337,6 +337,8 @@
 
 #define RPL_BATTLECLAN	     358
 
+#define RPL_BAD_LOGIN        378
+
 #define RPL_FIND_USER_EX     398
 
 #define RPL_UPDATE_RECORD    602
@@ -345,9 +347,10 @@
 #define RPL_ENDSERVLIST	     607
 #define RPL_GAMERESSERV	     608
 #define RPL_LADDERSERV	     609
-
 #define RPL_LOBCOUNT	     610
 
+#define ERR_GAMECHANCLOSED   478
+
 /** error's */
 /*
  * Errors are in the range from 400-599 currently and are grouped by what
